==> ejc-proequipmentcorp-impl-3.0.0-20230323.082600-355-sources.jar: com/ejianc/business/proequipmentcorprent/rent/service/impl/RentRentalBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorprent.rent.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.proequipmentcorprent.rent.bean.*;
import com.ejianc.business.proequipmentcorprent.rent.enums.RentEquipmentStateEnum;
import com.ejianc.business.proequipmentcorprent.rent.enums.RentParameterTypeEnum;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentParameterService;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentRentalService;
import com.ejianc.business.proequipmentcorprent.rent.vo.RentParameterVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service("rentRental") 
public class RentRentalBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IRentRentalService service;
	@Autowired
	private ICostDetailApi costDetailApi;
	/** 设备台账 */
	@Autowired
	private IRentParameterService parameterService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		RentRentalEntity entity = service.selectById(billId);
		logger.info("推送成本---");
//		service.costPush(entity);
		if ("1".equals(entity.getRentalType())) {
			// 5. 处理设备台账
			List<RentParameterVO> rentParameterList = parameterService.getRentParameterByContractId(entity.getContractId(),
							entity.getId(), entity.getRentalDate());
			List<RentParameterEntity> parameterEntityList = new ArrayList<>();
			for (RentParameterVO rentParameterVO : rentParameterList) {
				RentParameterEntity rentParameterEntity = BeanMapper.map(rentParameterVO, RentParameterEntity.class);
				rentParameterEntity.setOperationDate(entity.getRentalDate());
				// 处理子表
				List<RentParameterDetailEntity> parameterDetailList = new ArrayList<>();
				RentParameterDetailEntity detailEntity = new RentParameterDetailEntity();
				detailEntity.setSourceType(RentParameterTypeEnum.租金计算.getCode());
				detailEntity.setSourceId(entity.getId());
				detailEntity.setOperationDate(entity.getRentalDate());
				if(RentEquipmentStateEnum.停租.getCode().equals(rentParameterEntity.getEquipmentState())){
					detailEntity.setEquipmentState(4);
				}else{
					detailEntity.setEquipmentState(rentParameterEntity.getEquipmentState());
				}

				detailEntity.setParameterId(rentParameterEntity.getId());
				parameterDetailList.add(detailEntity);

				rentParameterEntity.setRentParameterDetailList(parameterDetailList);
				parameterEntityList.add(rentParameterEntity);
			}
			parameterService.changeParameter(parameterEntityList, RentParameterTypeEnum.租金计算.getCode());
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
        CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
        if(!resp.isSuccess()){
            return CommonResponse.error("无法撤回！"+resp.getMsg());
        }
		RentRentalEntity entity = service.selectById(billId);
		logger.info("弃审推送成本---");
		logger.info("删除成本中心之前的数据-Id---{}",entity.getId());
		CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(entity.getId());
		logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
		if(!stringCommonResponse.isSuccess()){
			throw new BusinessException(stringCommonResponse.getMsg());
		}
		//更新是否关联
		LambdaUpdateWrapper<RentRentalEntity> updateWrapper = new LambdaUpdateWrapper<>();
		updateWrapper.in(RentRentalEntity::getId, entity.getId());
		updateWrapper.set(RentRentalEntity::getRelationFlag, "0");//(1:是，0：否)
		service.update(updateWrapper);

		// 处理自动租金计算数据
		if ("1".equals(entity.getRentalType())) {
			List<Long> parameterIdList = new ArrayList<>();
			List<RentRentalDayEntity> dayList = entity.getRentRentalDayList(); // 租金计算日租明细
			List<RentRentalMonthEntity> monthList = entity.getRentRentalMonthList(); // 租金计算月租明细
			// 租金计算工程量租明细
			List<RentRentalQuantitiesEntity> qList = entity.getRentRentalQuantitiesList();
			if (CollectionUtils.isNotEmpty(dayList)) {
				List<Long> sourceIdList = dayList.stream().map(RentRentalDayEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}
			if (CollectionUtils.isNotEmpty(monthList)) {
				List<Long> sourceIdList = monthList.stream().map(RentRentalMonthEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}
			if (CollectionUtils.isNotEmpty(qList)) {
				List<Long> sourceIdList = qList.stream().map(RentRentalQuantitiesEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}
			parameterService.cancelParameter(parameterIdList, RentParameterTypeEnum.租金计算.getCode(), entity.getId());
		}
		return CommonResponse.success();
	}

}

==> ejc-proequipmentcorp-impl-3.0.0-20230525.035006-412-sources.jar: com/ejianc/business/proequipmentcorprent/rent/service/impl/RentRentalBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorprent.rent.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.ejianc.business.procost.api.ICostDetailApi;
import com.ejianc.business.proequipmentcorprent.rent.bean.*;
import com.ejianc.business.proequipmentcorprent.rent.enums.PerformanceStatusEnum;
import com.ejianc.business.proequipmentcorprent.rent.enums.RentEquipmentStateEnum;
import com.ejianc.business.proequipmentcorprent.rent.enums.RentParameterTypeEnum;
import com.ejianc.business.proequipmentcorprent.rent.enums.RentalSettlementStateEnum;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentContractService;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentParameterDetailService;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentParameterService;
import com.ejianc.business.proequipmentcorprent.rent.service.IRentRentalService;
import com.ejianc.business.proequipmentcorprent.rent.vo.RentParameterVO;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

@Service("rentRental") 
public class RentRentalBpmServiceImpl implements ICommonBusinessService {

    @Autowired
    private IBillTypeApi billTypeApi;
	private Logger logger = LoggerFactory.getLogger(this.getClass());

	@Autowired
	private IRentRentalService service;
	@Autowired
	private ICostDetailApi costDetailApi;
	/** 设备台账 */
	@Autowired
	private IRentParameterService parameterService;
	@Autowired
	private IRentParameterDetailService rentParameterDetailService;
	@Autowired
	private IRentContractService contractService;
	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		RentRentalEntity entity = service.selectById(billId);
		logger.info("推送成本---");
//		service.costPush(entity);
		if ("1".equals(entity.getRentalType())) {
			// 5. 处理设备台账
			List<RentParameterVO> rentParameterList = parameterService.getRentParameterByContractId(entity.getContractId(),
							entity.getId(), entity.getRentalDate());
			// 处理子表
			List<RentParameterDetailEntity> parameterDetailList = new ArrayList<>();
			for (RentParameterVO rentParameterVO : rentParameterList) {
				RentParameterEntity rentParameterEntity = BeanMapper.map(rentParameterVO, RentParameterEntity.class);

				RentParameterDetailEntity detailEntity = new RentParameterDetailEntity();
				detailEntity.setSourceType(RentParameterTypeEnum.租金计算.getCode());
				detailEntity.setSourceId(entity.getId());
				detailEntity.setOperationDate(entity.getRentalDate());

				QueryParam detailParam = new QueryParam();
				detailParam.getParams().put("parameterId", new Parameter(QueryParam.EQ, rentParameterEntity.getId()));
				detailParam.getOrderMap().put("createTime", QueryParam.DESC);
				List<RentParameterDetailEntity> detailList = rentParameterDetailService.queryList(detailParam, false);
				if(CollectionUtils.isNotEmpty(detailList)){
					detailEntity.setEquipmentState(detailList.get(0).getEquipmentState());
				}else{
					//正常不会走到此处
					detailEntity.setEquipmentState(rentParameterEntity.getEquipmentState());
				}
				detailEntity.setParameterId(rentParameterEntity.getId());
				parameterDetailList.add(detailEntity);
			}
			if (CollectionUtils.isNotEmpty(parameterDetailList)) {
				// 插入操作记录
				rentParameterDetailService.saveOrUpdateBatch(parameterDetailList);
			}
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
        CommonResponse<String> resp = billTypeApi.checkQuote(billTypeCode, billId);
        if(!resp.isSuccess()){
            return CommonResponse.error("无法撤回！"+resp.getMsg());
        }
		RentRentalEntity entity = service.selectById(billId);
		RentContractEntity contractEntity = contractService.selectById(entity.getContractId());
		if(contractEntity !=null && PerformanceStatusEnum.已终止.getCode().equals(contractEntity.getContractPerformanceState())){
			return CommonResponse.error("合同已终止，该单据不能撤回！");
		}
		if (RentalSettlementStateEnum.已结算.getCode().equals(entity.getSettlementState())){
			return CommonResponse.error("当前单据已结算，不能弃审！");
		}
		if(entity.getContractId()!=null){
			LambdaQueryWrapper<RentRentalEntity> lambda = new LambdaQueryWrapper<>();
			lambda.eq(RentRentalEntity::getContractId, entity.getContractId());
			lambda.orderByDesc(RentRentalEntity::getCreateTime);
			List<RentRentalEntity> list = service.list(lambda);
			RentRentalEntity rentRentalEntity = list.get(0);
			if(!entity.getId().equals(rentRentalEntity.getId())){
				throw new BusinessException("只能撤回最新的结算单！");
			}
		}
		logger.info("弃审推送成本---");
		logger.info("删除成本中心之前的数据-Id---{}",entity.getId());
		CommonResponse<String> stringCommonResponse = costDetailApi.deleteSubject(entity.getId());
		logger.info("结果"+ JSONObject.toJSONString(stringCommonResponse));
		if(!stringCommonResponse.isSuccess()){
			throw new BusinessException(stringCommonResponse.getMsg());
		}
		//更新是否关联
		LambdaUpdateWrapper<RentRentalEntity> updateWrapper = new LambdaUpdateWrapper<>();
		updateWrapper.in(RentRentalEntity::getId, entity.getId());
		updateWrapper.set(RentRentalEntity::getRelationFlag, "0");//(1:是，0：否)
		service.update(updateWrapper);

		// 处理自动租金计算数据
		if ("1".equals(entity.getRentalType())) {
			List<Long> parameterIdList = new ArrayList<>();
			List<RentRentalDayEntity> dayList = entity.getRentRentalDayList(); // 租金计算日租明细
			List<RentRentalMonthEntity> monthList = entity.getRentRentalMonthList(); // 租金计算月租明细
			// 租金计算工程量租明细
			List<RentRentalQuantitiesEntity> qList = entity.getRentRentalQuantitiesList();
			if (CollectionUtils.isNotEmpty(dayList)) {
				List<Long> sourceIdList = dayList.stream().map(RentRentalDayEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}
			if (CollectionUtils.isNotEmpty(monthList)) {
				List<Long> sourceIdList = monthList.stream().map(RentRentalMonthEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}
			if (CollectionUtils.isNotEmpty(qList)) {
				List<Long> sourceIdList = qList.stream().map(RentRentalQuantitiesEntity::getSourceId).collect(Collectors.toList());
				parameterIdList.addAll(sourceIdList);
			}

			QueryParam detailParam = new QueryParam();
			detailParam.getParams().put("parameterId", new Parameter(QueryParam.IN, parameterIdList));
			detailParam.getParams().put("source_id",new Parameter(QueryParam.EQ, billId));
			detailParam.getOrderMap().put("createTime", QueryParam.DESC);
			List<RentParameterDetailEntity> parameterDetailList = rentParameterDetailService.queryList(detailParam, false);
			if(CollectionUtils.isNotEmpty(parameterDetailList)){
				rentParameterDetailService.removeByIds(parameterDetailList.stream().map(RentParameterDetailEntity::getId).collect(Collectors.toList()));
			}
		}
		return CommonResponse.success();
	}

}
